==> arrow-docs-0.8.1-sources.jar: com/example/domain/Address$$optics.kt <==
package `com`.`example`.`domain`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `com`.`example`.`domain`.`Address`.Companion.iso: arrow.optics.Iso<`com`.`example`.`domain`.`Address`, arrow.core.Tuple2<`kotlin`.`String`, `com`.`example`.`domain`.`Street`>> inline get()= arrow.optics.Iso(
  get = { address: `com`.`example`.`domain`.`Address` -> arrow.core.Tuple2(address.`city`, address.`street`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`String`, `com`.`example`.`domain`.`Street`> -> `com`.`example`.`domain`.`Address`(tuple.a, tuple.b) }
)

inline val `com`.`example`.`domain`.`Address`.Companion.city: arrow.optics.Lens<`com`.`example`.`domain`.`Address`, `kotlin`.`String`> inline get()= arrow.optics.Lens(
  get = { address: `com`.`example`.`domain`.`Address` -> address.`city` },
  set = { value: `kotlin`.`String` ->
    { address: `com`.`example`.`domain`.`Address` ->
      address.copy(`city` = value)
    }
  }
)

inline val `com`.`example`.`domain`.`Address`.Companion.street: arrow.optics.Lens<`com`.`example`.`domain`.`Address`, `com`.`example`.`domain`.`Street`> inline get()= arrow.optics.Lens(
  get = { address: `com`.`example`.`domain`.`Address` -> address.`street` },
  set = { value: `com`.`example`.`domain`.`Street` ->
    { address: `com`.`example`.`domain`.`Address` ->
      address.copy(`street` = value)
    }
  }
)




inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Address`>.city: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Address`.city
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Address`>.city: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Address`.city
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Address`>.city: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Address`.city
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Address`>.city: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Address`.city
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`Address`>.city: arrow.optics.Getter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Address`.city
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Address`>.city: arrow.optics.Setter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Address`.city
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Address`>.city: arrow.optics.Traversal<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Address`.city
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Address`>.city: arrow.optics.Fold<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Address`.city

inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Address`>.street: arrow.optics.Lens<S, `com`.`example`.`domain`.`Street`> inline get() = this + `com`.`example`.`domain`.`Address`.street
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Address`>.street: arrow.optics.Lens<S, `com`.`example`.`domain`.`Street`> inline get() = this + `com`.`example`.`domain`.`Address`.street
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Address`>.street: arrow.optics.Optional<S, `com`.`example`.`domain`.`Street`> inline get() = this + `com`.`example`.`domain`.`Address`.street
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Address`>.street: arrow.optics.Optional<S, `com`.`example`.`domain`.`Street`> inline get() = this + `com`.`example`.`domain`.`Address`.street
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`Address`>.street: arrow.optics.Getter<S, `com`.`example`.`domain`.`Street`> inline get() = this + `com`.`example`.`domain`.`Address`.street
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Address`>.street: arrow.optics.Setter<S, `com`.`example`.`domain`.`Street`> inline get() = this + `com`.`example`.`domain`.`Address`.street
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Address`>.street: arrow.optics.Traversal<S, `com`.`example`.`domain`.`Street`> inline get() = this + `com`.`example`.`domain`.`Address`.street
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Address`>.street: arrow.optics.Fold<S, `com`.`example`.`domain`.`Street`> inline get() = this + `com`.`example`.`domain`.`Address`.street

==> arrow-docs-0.10.3-sources.jar: com/example/domain/Address$$optics.kt <==
package `com`.`example`.`domain`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `com`.`example`.`domain`.`Address`.Companion.iso: arrow.optics.Iso<`com`.`example`.`domain`.`Address`, arrow.core.Tuple2<`kotlin`.`String`, `com`.`example`.`domain`.`Street`>> inline get()= arrow.optics.Iso(
  get = { address: `com`.`example`.`domain`.`Address` -> arrow.core.Tuple2(address.`city`, address.`street`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`String`, `com`.`example`.`domain`.`Street`> -> `com`.`example`.`domain`.`Address`(tuple.a, tuple.b) }
)

inline val `com`.`example`.`domain`.`Address`.Companion.city: arrow.optics.Lens<`com`.`example`.`domain`.`Address`, `kotlin`.`String`> inline get()= arrow.optics.Lens(
  get = { address: `com`.`example`.`domain`.`Address` -> address.`city` },
  set = { address: `com`.`example`.`domain`.`Address`, value: `kotlin`.`String` -> address.copy(`city` = value) }
)

inline val `com`.`example`.`domain`.`Address`.Companion.street: arrow.optics.Lens<`com`.`example`.`domain`.`Address`, `com`.`example`.`domain`.`Street`> inline get()= arrow.optics.Lens(
  get = { address: `com`.`example`.`domain`.`Address` -> address.`street` },
  set = { address: `com`.`example`.`domain`.`Address`, value: `com`.`example`.`domain`.`Street` -> address.copy(`street` = value) }
)




inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Address`>.city: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Address`.city
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Address`>.city: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Address`.city
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Address`>.city: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Address`.city
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Address`>.city: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Address`.city
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`Address`>.city: arrow.optics.Getter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Address`.city
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Address`>.city: arrow.optics.Setter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Address`.city
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Address`>.city: arrow.optics.Traversal<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Address`.city
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Address`>.city: arrow.optics.Fold<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Address`.city

inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Address`>.street: arrow.optics.Lens<S, `com`.`example`.`domain`.`Street`> inline get() = this + `com`.`example`.`domain`.`Address`.street
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Address`>.street: arrow.optics.Lens<S, `com`.`example`.`domain`.`Street`> inline get() = this + `com`.`example`.`domain`.`Address`.street
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Address`>.street: arrow.optics.Optional<S, `com`.`example`.`domain`.`Street`> inline get() = this + `com`.`example`.`domain`.`Address`.street
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Address`>.street: arrow.optics.Optional<S, `com`.`example`.`domain`.`Street`> inline get() = this + `com`.`example`.`domain`.`Address`.street
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`Address`>.street: arrow.optics.Getter<S, `com`.`example`.`domain`.`Street`> inline get() = this + `com`.`example`.`domain`.`Address`.street
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Address`>.street: arrow.optics.Setter<S, `com`.`example`.`domain`.`Street`> inline get() = this + `com`.`example`.`domain`.`Address`.street
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Address`>.street: arrow.optics.Traversal<S, `com`.`example`.`domain`.`Street`> inline get() = this + `com`.`example`.`domain`.`Address`.street
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Address`>.street: arrow.optics.Fold<S, `com`.`example`.`domain`.`Street`> inline get() = this + `com`.`example`.`domain`.`Address`.street
